---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: ''
assignees: ''

---

# Feature Request

**If your feature request is related to a problem, please describe the problem.**

A clear and concise description of what the problem is. e.g. `I'm always frustrated when [...]`.

**Describe the solution you would like**
A clear and concise description of what you want to happen.

**Describe alternatives you've considered**
A clear and concise description of any alternative solutions or features you've considered.

**Additional context**
Add any other context or screenshots about the feature request here.

Thanks :+1: !